import requests
from json import loads
from urllib.parse import quote
from r3c0nutils.user_agent import GET_UA

class Riddler:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def riddler_script(self, domain):
        self.subdomain_lst = []
        RIDDLER_USERNAME = ''
        RIDDLER_PASSWORD = ''
        if RIDDLER_USERNAME == "" or RIDDLER_PASSWORD == "":
            print("No Riddler API credentials configured")
            return self.subdomain_lst
        else:
            auth = {"email": RIDDLER_USERNAME, "password": RIDDLER_PASSWORD}
            auth_url = "https://riddler.io/auth/login"
            headers = {"User-Agent": GET_UA()}
            try:
                res = requests.post(auth_url, json=auth, headers=headers, timeout=10)
                res.raise_for_status()
                res_json = loads(res.text)

                if res_json["meta"]["code"] == 200:
                    auth_token = res_json["response"]["user"]["authentication_token"]
                    search = {"query": "pld:{0}".format(quote(domain)), "output": "host"}
                    search_url = "https://riddler.io/api/search"
                    headers = {"User-Agent": GET_UA(), "Content-Type": "application/json", "Authentication-Token": auth_token}
                    search_response = requests.post(search_url, json=search, headers=headers)
                    if search_response.status_code == 200:
                        search_response_json = loads(search_response.text)
                    else:
                        print("An error occurred.")
                        return self.subdomain_lst

                    for item in search_response_json:
                        self.subdomain_lst.append(item["host"])
            except requests.exceptions.RequestException as err:
                raise Exception("Request Exception:", err)
            except requests.exceptions.HTTPError as errh:
                raise Exception("HTTP Error:", errh)
            except requests.exceptions.ConnectionError as errc:
                raise Exception("Connection Error:", errc)
            except requests.exceptions.Timeout as errt:
                raise Exception("Timeout Error:", errt) 
            else:
                return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.riddler_script(self.domain)
        return subdomain_result


from r3c0n.engines.anubis import Anubis
from r3c0n.engines.hacker_target import HackerTarget
from r3c0n.engines.open_threat import OpenThreat
from r3c0n.engines.project_sonar import ProjectSonar
from r3c0n.engines.threatcrowd import ThreatCrowd

class All:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def subdomains(self):
        subdomain_result = set()        
        subdomain_result = set.union(subdomain_result, set(Anubis(self.domain).subdomains()))
        subdomain_result = set.union(subdomain_result, set(HackerTarget(self.domain).subdomains()))
        subdomain_result = set.union(subdomain_result, set(OpenThreat(self.domain).subdomains()))
        subdomain_result = set.union(subdomain_result, set(ProjectSonar(self.domain).subdomains()))
        subdomain_result = set.union(subdomain_result, set(ThreatCrowd(self.domain).subdomains()))
        return list(subdomain_result)

all = All('coda.io').subdomains()
print(all)


import requests
from r3c0nutils.user_agent import GET_UA
from bs4 import BeautifulSoup

class FindSubdomains:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def findsubdomains_script(self, domain):
        """Returns the list of subdomains from the FindSubdomain website.

        Args:
            domain: An inscope domain in which the subdomains are required.
        Returns:
            A list of subdomains extracted from the Anubis database.
        Raises:
            RequestError: Raised on wrong request type.
            HTTPError: Raised on malformed HTTP request.
            ConnectionError: Raised when fails to connect to the server.
            TimeoutError: Raised when request takes too long to come back.
        """
        headers = {"User-Agent": GET_UA()}
        url = "https://findsubdomains.com/subdomains-of/{}".format(domain)
        try:
            res = requests.get(url, headers=headers, verify=False, timeout=10)
            res.raise_for_status()
            name_soup = BeautifulSoup(res.text, "html.parser")
            for link in name_soup.findAll("a", {"class": "aggregated-link"}):
                try:
                    if link.string is not None:
                        self.subdomain_lst.append(link.string.strip())
                except KeyError as errk:
                    return []
        except requests.exceptions.RequestException as err:
            raise Exception("Request Exception:", err)
        except requests.exceptions.HTTPError as errh:
            raise Exception("HTTP Error:", errh)
        except requests.exceptions.ConnectionError as errc:
            raise Exception("Connection Error:", errc)
        except requests.exceptions.Timeout as errt:
            raise Exception("Timeout Error:", errt) 
        else:
            return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.findsubdomains_script(self.domain)
        return subdomain_result


import json
import requests

class ThreatCrowd:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def threatcrowd_script(self, domain):
        try:
            res = requests.get("https://www.threatcrowd.org/searchApi/v2/domain/report/", params={"domain": domain}, timeout=10)
            res.raise_for_status()
            response = json.loads(res.text)
            resp_code = int(response["response_code"])
            if resp_code == 1:
                for sd in response["subdomains"]:
                    self.subdomain_lst.append(sd)
        except requests.exceptions.RequestException as err:
            raise Exception("Request Exception:", err)
        except requests.exceptions.HTTPError as errh:
            raise Exception("HTTP Error:", errh)
        except requests.exceptions.ConnectionError as errc:
            raise Exception("Connection Error:", errc)
        except requests.exceptions.Timeout as errt:
            raise Exception("Timeout Error:", errt)
        else:
            return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.threatcrowd_script(self.domain)
        return subdomain_result


import random

def GET_UA():
    uastrings = [
        "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36",\
        "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/28.0.1500.72 Safari/537.36",\
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10) AppleWebKit/600.1.25 (KHTML, like Gecko) Version/8.0 Safari/600.1.25",\
        "Mozilla/5.0 (Windows NT 6.1; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0",\
        "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36",\
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.111 Safari/537.36",\
        "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_9_5) AppleWebKit/600.1.17 (KHTML, like Gecko) Version/7.1 Safari/537.85.10",\
        "Mozilla/5.0 (Windows NT 6.1; WOW64; Trident/7.0; rv:11.0) like Gecko",\
        "Mozilla/5.0 (Windows NT 6.3; WOW64; rv:33.0) Gecko/20100101 Firefox/33.0",\
        "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/38.0.2125.104 Safari/537.36"\
        ]
 
    return random.choice(uastrings)


import requests
from urllib.parse import quote
from r3c0nutils.user_agent import GET_UA

class HackerTarget:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []
       
    def hackertarget_script(self, domain):
        url = "https://api.hackertarget.com/hostsearch/?q={0}".format(quote(domain))
        headers = {"user-agent": GET_UA()}
        try:
            res = requests.get(url, headers=headers, timeout=10).text
            hostnames = [result.split(",")[0] for result in res.split("\n")]

            for hostname in hostnames:
                if hostname:
                    self.subdomain_lst.append(hostname)
        except requests.exceptions.RequestException as err:
            raise Exception("Request Exception:", err)
        except requests.exceptions.HTTPError as errh:
            raise Exception("HTTP Error:", errh)
        except requests.exceptions.ConnectionError as errc:
            raise Exception("Connection Error:", errc)
        except requests.exceptions.Timeout as errt:
            raise Exception("Timeout Error:", errt) 
        else:
            return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.hackertarget_script(self.domain)
        return subdomain_result


import requests
from json import loads
from r3c0nutils.user_agent import GET_UA

class ProjectSonar:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def filterDomain(self, domain, subdomain_lst):
        domain_parts = domain.split(".")
        filtered = []
        for subdomain in subdomain_lst:
            subdomain_parts = subdomain.split(".")
            if domain_parts == subdomain_parts[-1 * len(domain_parts):]:
                filtered.append(subdomain)

        return filtered

    def projectsonar_script(self, domain):
        url = "http://dns.bufferover.run/dns?q=.{0}".format(domain)
        try:
            headers = {"User-Agent": GET_UA()}
            res = requests.get(url, headers=headers, timeout=10)
            res.raise_for_status()
            response_json = loads(res.text)

            if response_json["FDNS_A"]:
                for record in response_json["FDNS_A"]:
                    self.subdomain_lst += record.split(",")

            if response_json["RDNS"]:
                for record in response_json["RDNS"]:
                    self.subdomain_lst.append(record.split(",")[1])

            self.subdomain_lst = self.filterDomain(domain, set([subdomain.lower() for subdomain in self.subdomain_lst]))
        except requests.exceptions.RequestException as err:
            raise Exception("Request Exception:", err)
        except requests.exceptions.HTTPError as errh:
            raise Exception("HTTP Error:", errh)
        except requests.exceptions.ConnectionError as errc:
            raise Exception("Connection Error:", errc)
        except requests.exceptions.Timeout as errt:
            raise Exception("Timeout Error:", errt) 
        else:
            return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.projectsonar_script(self.domain)
        return subdomain_result




import requests
from r3c0nutils.user_agent import GET_UA

class Anubis:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def anubis_script(self, domain):
        """Returns the list of subdomains from the Anuibis Database.

        Args:
            domain: An inscope domain in which the subdomains are required.
        Returns:
            A list of subdomains extracted from the Anubis database.
        Raises:
            RequestError: Raised on wrong request type.
            HTTPError: Raised on malformed HTTP request.
            ConnectionError: Raised when fails to connect to the server.
            TimeoutError: Raised when request takes too long to come back.
        """
        headers = {"User-Agent": GET_UA(), "Content-Type": "application/json"}
        try:
            res = requests.get("https://jldc.me/anubis/subdomains/" + domain, headers=headers, timeout=10)
            res.raise_for_status()
            stripped_response = res.text.strip().split(",")
            for id, res in enumerate(stripped_response):
                res = res.replace('"', '')
                if id == 0:
                    res = res[1:]
                if id == len(stripped_response)-1:
                    res = res[:-1]
                self.subdomain_lst.append(res)
        except requests.exceptions.RequestException as err:
            raise Exception("Request Exception:", err)
        except requests.exceptions.HTTPError as errh:
            raise Exception("HTTP Error:", errh)
        except requests.exceptions.ConnectionError as errc:
            raise Exception("Connection Error:", errc)
        except requests.exceptions.Timeout as errt:
            raise Exception("Timeout Error:", errt)
        else:
            return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.anubis_script(self.domain)
        return subdomain_result


from r3c0nutils.user_agent import GET_UA
import requests

class VirusTotal:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def virustotal_script(self, domain):
        VT_API_KEY = ""

        if VT_API_KEY == "":
            print("No VirusTotal API key configured", "red")
            return self.subdomain_lst
        else:
            parameters = {"domain": domain, "apikey": VT_API_KEY}
            headers = {"User-Agent": GET_UA()}
            try:
                res = requests.get("https://www.virustotal.com/vtapi/v2/domain/report", params=parameters, headers=headers, timeout=10)
                res.raise_for_status()
                response_dict = res.json()
                if "subdomains" in response_dict:
                    for sd in response_dict["subdomains"]:
                        self.subdomain_lst.append(sd)
            except requests.exceptions.RequestException as err:
                raise Exception("Request Exception:", err)
            except requests.exceptions.HTTPError as errh:
                raise Exception ("HTTP Error:", errh)
            except requests.exceptions.ConnectionError as errc:
                raise Exception("Connection Error:", errc)
            except requests.exceptions.Timeout as errt:
                raise Exception("Timeout Error:", errt)
            else:
                return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.virustotal_script(self.domain)
        return subdomain_result


import json
import requests
from r3c0nutils.formatter import Clean
from r3c0nutils.user_agent import GET_UA

class OpenThreat:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def openthreat_script(self, domain):
        self.subdomain_lst = []
        headers = {"User-Agent": GET_UA(), "Content-Type": "application/json"}
        try:
            res = requests.get("https://otx.alienvault.com/otxapi/indicator/hostname/url_list/" + domain, headers=headers, timeout=10)
            res.raise_for_status()
            if res.status_code == 200:
                data = json.loads(res.text)
                for d in data["url_list"]:
                    self.subdomain_lst.append(d["url"])
        except requests.exceptions.RequestException as err:
            raise Exception("Request Exception:", err)
        except requests.exceptions.HTTPError as errh:
            raise Exception("HTTP Error:", errh)
        except requests.exceptions.ConnectionError as errc:
            raise Exception("Connection Error:", errc)
        except requests.exceptions.Timeout as errt:
            raise Exception("Timeout Error:", errt) 
        else:
            return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.openthreat_script(self.domain)
        subdomain_result = Clean(subdomain_result)
        return subdomain_result


import requests
import json
import os

class Shodan:
    def __init__(self, domain):
        self.domain = domain
        self.subdomain_lst = []

    def sorter(self, subdomains):
        local, final = [], []
        for item in subdomains:
            reversed_sub = ".".join(str(item).split('.')[::-1])
            local.append(reversed_sub)

        sortedlist = sorted(local)
        for item in sortedlist:
            d_reversed_sub = ".".join(str(item).split('.')[::-1])
            final.append(d_reversed_sub)
        return final

    def shodan_script(self, domain):
        subdomains = []
        self.subdomain_lst = []
        SHODAN_API = "UNmOjxeFS2mPA3kmzm1sZwC0XjaTTksy"
        if SHODAN_API == "":
            print("No Riddler API credentials configured")
            return self.subdomain_lst
        else:
            try:
                res = requests.get('https://api.shodan.io/dns/domain/' + domain + '?key=' + SHODAN_API, timeout=10)
                res.raise_for_status()
                data = json.loads(res.text)
                if 'error' in data:
                    self.subdomain_lst = []
                else:
                    for item in data["data"]:
                        entry = item["subdomain"]  
                        record_type = item["type"]
                        value = item["value"]
                        if record_type == 'CNAME' and domain in value: 
                            delim = value.split('.')
                            match = delim[-2] + '.' + delim[-1]
                            if match == domain:
                                subdomains.add(value)

                    for url in self.sorter(subdomains): 
                        self.subdomain_lst.append(url)
            except requests.exceptions.RequestException as err:
                raise Exception("Request Exception:", err)
            except requests.exceptions.HTTPError as errh:
                raise Exception("HTTP Error:", errh)
            except requests.exceptions.ConnectionError as errc:
                raise Exception("Connection Error:", errc)
            except requests.exceptions.Timeout as errt:
                raise Exception("Timeout Error:", errt) 
            else:
                return self.subdomain_lst

    def subdomains(self):
        subdomain_result = self.shodan_script(self.domain)
        return subdomain_result